THIS IS AN AUTOMATED MESSAGE, DO NOT REPLY.
The following task is now closed:
FS#16 - Local 487 forwarded upstream
User who did this - Andrei Pelinescu-Onciul (andrei)
Reason for closing: Not a bug
More information can be found at the following URL:
http://sip-router.org/tracker/index.php?do=details&task_id=16
You are receiving this message because you have requested it from the Flyspray bugtracking system. If you did not expect this message or don't want to receive mails in future, you can change your notification settings at the URL shown above.
THIS IS AN AUTOMATED MESSAGE, DO NOT REPLY.
The following task has been changed. The changes are listed below. For full information about what has changed, visit the URL and click the History tab.
FS#21 - Crash at t_reply.c:668
User who did this: Andrei Pelinescu-Onciul (andrei)
Percent Complete: 0% -> 90%
Status: Assigned -> Requires testing
More information can be found at the following URL:
http://sip-router.org/tracker/index.php?do=details&task_id=21
You are receiving this message because you have requested it from the Flyspray bugtracking system. If you did not expect this message or don't want to receive mails in future, you can change your notification settings at the URL shown above.
Hi!
I use kamailio-rc3.
After lookup(), sometimes DURI of a branch is populated although
"received" column is null for this contact. Sometimes, DURI is correct
and <null>.
Looks like it contains some old value. Any hints how to debug problem?
regards
klaus
THIS IS AN AUTOMATED MESSAGE, DO NOT REPLY.
The following task has a new comment added:
FS#21 - Crash at t_reply.c:668
User who did this - Andrei Pelinescu-Onciul (andrei)
----------
It looks there is a local transaction (probably created by one of the modules you use?).
There was a related problem with drop_replies in the kamailio_3.0 branch fixed
earlier today in a883a0b2501ba2b25ca87994d4c211f75a556ebe. This commit should also fix your crash.
The crash happens in the error path for failed branches, when it is executed for a local transaction. The commit above fixed a bug that wrongly triggered the error path.
I've made another fix in the sr_3.0 branch, that should avoid the problem even if the error path would be called sometime in the future (right now it should not be possible to trigger it for local replies).
----------
More information can be found at the following URL:
http://sip-router.org/tracker/index.php?do=details&task_id=21#comment14
You are receiving this message because you have requested it from the Flyspray bugtracking system. If you did not expect this message or don't want to receive mails in future, you can change your notification settings at the URL shown above.
Module: sip-router
Branch: sr_3.0
Commit: 0fe25e507eccac409f5094cff4240ee5d3224666
URL: http://git.sip-router.org/cgi-bin/gitweb.cgi/sip-router/?a=commit;h=0fe25e5…
Author: Andrei Pelinescu-Onciul <andrei(a)iptel.org>
Committer: Andrei Pelinescu-Onciul <andrei(a)iptel.org>
Date: Wed Dec 23 20:44:31 2009 +0100
tm: safer handling for local transactions and drop_replies!=0
- if all the replies are dropped in the failure route and the
transaction is local, return the current reply. This makes the
code more future safe (currently there is no way for the failure
route to be executed and hence for replies to be dropped for
local transactions).
- check for FAKED_REPLY in local_reply() error path.
---
modules/tm/t_reply.c | 23 +++++++++++++----------
1 files changed, 13 insertions(+), 10 deletions(-)
diff --git a/modules_s/blst/README b/modules_s/blst/README
index 8387e98..44b966e 100644
--- a/modules_s/blst/README
+++ b/modules_s/blst/README
@@ -16,6 +16,11 @@ Andrei Pelinescu-Onciul
1.2.2. blst_add_retry_after(min, max)
1.2.3. blst_del()
1.2.4. blst_is_blacklisted()
+ 1.2.5. blst_set_ignore() blst_set_ignore(flags)
+ blst_rpl_set_ignore() blst_rpl_set_ignore(flags)
+
+ 1.2.6. blst_clear_ignore() blst_clear_ignore(flags)
+ blst_rpl_clear_ignore() blst_rpl_clear_ignore(flags)
1.1. Overview
@@ -80,3 +85,45 @@ if (msg_status==503){ # blacklist 503 source for Retry-After seconds
drop;
}
...
+
+1.2.5. blst_set_ignore() blst_set_ignore(flags) blst_rpl_set_ignore()
+blst_rpl_set_ignore(flags)
+
+ Set errors that will not be taken into account when deciding whether or
+ not to blacklist a destination for the current message or a local reply
+ to the current message.
+
+ blst_set_ignore(..) works for forwarding the current message and
+ blst_rpl_set_ignore(...) works for local replies to the current
+ message.
+
+ The variants with no parameters will ignore everything (equivalent with
+ passing 0xff).
+
+ The following flags are defined:
+ * 0x02 - generic send error (send denied/ failed).
+ * 0x04 - connect failed (TCP, TLS or SCTP).
+ * 0x08 - ICMP error (not currently used).
+ * 0x10 - SIP transaction timeout.
+ * 0x20 - 503 reply (statefull mode only). For more details see
+ tmblst_503.
+
+Note
+
+ TCP and TLS send and connect errors are handled per connection and not
+ per message. The connection blacklist ignore flags are inherithed from
+ the message that caused the connection establishment.
+
+ Example 5. blst_set_ignore usage
+ blst_set_ignore(6); # ignore send and connect errors
+
+1.2.6. blst_clear_ignore() blst_clear_ignore(flags) blst_rpl_clear_ignore()
+blst_rpl_clear_ignore(flags)
+
+ Clears blacklist ignore flags previously set by the corresponding
+ blst_set_ignore(...) or blst_rpl_set_ignore(...) functions.
+
+ See also blst_set_ignore.
+
+ Example 6. blst_clear_ignore usage
+ blst_clear_ignore(4); # ignore connect errors
diff --git a/modules_s/blst/doc/functions.xml b/modules_s/blst/doc/functions.xml
index a26f8b8..86bd87b 100644
--- a/modules_s/blst/doc/functions.xml
+++ b/modules_s/blst/doc/functions.xml
@@ -108,4 +108,84 @@ if (msg_status==503){ # blacklist 503 source for Retry-After seconds
</example>
</section>
+ <section id="blst_set_ignore">
+ <title>
+ <function>blst_set_ignore()</function>
+ <function>blst_set_ignore(flags)</function>
+ <function>blst_rpl_set_ignore()</function>
+ <function>blst_rpl_set_ignore(flags)</function>
+ </title>
+ <para>
+ Set errors that will not be taken into account when deciding
+ whether or not to blacklist a destination for the current message
+ or a local reply to the current message.
+ </para>
+ <para>
+ <function>blst_set_ignore(..)</function> works for forwarding the
+ current message and <function>blst_rpl_set_ignore(...)</function>
+ works for local replies to the current message.
+ </para>
+ <para>
+ The variants with no parameters will ignore everything (equivalent
+ with passing 0xff).
+ </para>
+ <para>
+ The following flags are defined:
+ <itemizedlist>
+ <listitem>
+ <emphasis>0x02</emphasis> - generic send error (send denied/
+ failed).
+ </listitem>
+ <listitem>
+ <emphasis>0x04</emphasis> - connect failed (TCP, TLS or SCTP).
+ </listitem>
+ <listitem>
+ <emphasis>0x08</emphasis> - ICMP error (not currently used).
+ </listitem>
+ <listitem>
+ <emphasis>0x10</emphasis> - SIP transaction timeout.
+ </listitem>
+ <listitem>
+ <emphasis>0x20</emphasis> - 503 reply (statefull mode only).
+ For more details see <emphasis>tm</emphasis>
+ <varname>blst_503</varname>.
+ </listitem>
+ </itemizedlist>
+ </para>
+ <note>
+ TCP and TLS send and connect errors are handled per connection and
+ not per message. The connection blacklist ignore flags are inherithed
+ from the message that caused the connection establishment.
+ </note>
+ <example>
+ <title><function>blst_set_ignore</function> usage</title>
+ <programlisting>
+ blst_set_ignore(6); # ignore send and connect errors
+ </programlisting>
+ </example>
+ </section>
+
+ <section id="blst_clear_ignore">
+ <title>
+ <function>blst_clear_ignore()</function>
+ <function>blst_clear_ignore(flags)</function>
+ <function>blst_rpl_clear_ignore()</function>
+ <function>blst_rpl_clear_ignore(flags)</function>
+ </title>
+ <para>
+ Clears blacklist ignore flags previously set by the corresponding
+ <function>blst_set_ignore(...)</function> or
+ <function>blst_rpl_set_ignore(...)</function> functions.
+ </para>
+ <para>
+ See also <function>blst_set_ignore</function>.
+ </para>
+ <example>
+ <title><function>blst_clear_ignore</function> usage</title>
+ <programlisting>
+ blst_clear_ignore(4); # ignore connect errors
+ </programlisting>
+ </example>
+ </section>
+
</section>
diff --git a/modules/tm/t_reply.c b/modules/tm/t_reply.c
index 8dbd1d6..12af017 100644
--- a/modules/tm/t_reply.c
+++ b/modules/tm/t_reply.c
@@ -1248,16 +1248,19 @@ discard:
branches_failed:
*should_store=0;
- *should_relay=-1;
- /* We have hopefully set tm_error in failure_route when
- the branches failed. If not, reply with E_UNSPEC */
- if ((kill_transaction_unsafe(Trans,
- tm_error ? tm_error : E_UNSPEC)
- ) <=0 ){
- LOG(L_ERR, "ERROR: t_should_relay_response: "
- "reply generation failed\n");
+ if (is_local(Trans)){
+ /* for local transactions use the current reply */
+ *should_relay=branch;
+ }else{
+ *should_relay=-1;
+ /* We have hopefully set tm_error in failure_route when
+ the branches failed. If not, reply with E_UNSPEC */
+ if ((kill_transaction_unsafe(Trans,
+ tm_error ? tm_error : E_UNSPEC)) <=0 ){
+ LOG(L_ERR, "ERROR: t_should_relay_response: "
+ "reply generation failed\n");
+ }
}
-
return RPS_COMPLETED;
}
@@ -1802,7 +1805,7 @@ error:
prepare_to_cancel(t, cancel_bitmap, 0);
UNLOCK_REPLIES(t);
cleanup_uac_timers(t);
- if ( get_cseq(p_msg)->method.len==INVITE_LEN
+ if (p_msg && p_msg!=FAKED_REPLY && get_cseq(p_msg)->method.len==INVITE_LEN
&& memcmp( get_cseq(p_msg)->method.s, INVITE, INVITE_LEN)==0)
cancel_uacs( t, *cancel_bitmap, F_CANCEL_B_KILL);
*cancel_bitmap=0; /* we've already took care of everything */
THIS IS AN AUTOMATED MESSAGE, DO NOT REPLY.
Daniel-Constantin Mierla has taken ownership of the following task:
FS#22 - $shv problems
More information can be found at the following URL:
http://sip-router.org/tracker/index.php?do=details&task_id=22
You are receiving this message because you have requested it from the Flyspray bugtracking system. If you did not expect this message or don't want to receive mails in future, you can change your notification settings at the URL shown above.
THIS IS AN AUTOMATED MESSAGE, DO NOT REPLY.
The following task has a new comment added:
FS#22 - $shv problems
User who did this - Daniel-Constantin Mierla (miconda)
----------
Indeed it is a problem with $sht(). I found where, looking for a solution now. Thanks!
----------
More information can be found at the following URL:
http://sip-router.org/tracker/index.php?do=details&task_id=22#comment13
You are receiving this message because you have requested it from the Flyspray bugtracking system. If you did not expect this message or don't want to receive mails in future, you can change your notification settings at the URL shown above.
THIS IS AN AUTOMATED MESSAGE, DO NOT REPLY.
The following task has a new comment added:
FS#21 - Crash at t_reply.c:668
User who did this - Andrey 'Krieger' Utkin (andrey.utkin.2)
----------
I reproduced it one more time, this time both proxies crashed X-(
Sorry that i post not precisely cutted log files this time, .ngrep files have long tail representing that kamailio is down.
In .log files there are cores backtraces also.
----------
One or more files have been attached.
More information can be found at the following URL:
http://sip-router.org/tracker/index.php?do=details&task_id=21#comment12
You are receiving this message because you have requested it from the Flyspray bugtracking system. If you did not expect this message or don't want to receive mails in future, you can change your notification settings at the URL shown above.
Module: sip-router
Branch: andrei/blst_send_flags
Commit: d322fc29ab9a5edce1f826de2a5de141aab09e1f
URL: http://git.sip-router.org/cgi-bin/gitweb.cgi/sip-router/?a=commit;h=d322fc2…
Author: Andrei Pelinescu-Onciul <andrei(a)iptel.org>
Committer: Andrei Pelinescu-Onciul <andrei(a)iptel.org>
Date: Wed Dec 23 18:13:35 2009 +0100
blst: docs for blst_{set,clear}_ignore script functions
---
modules_s/blst/README | 47 ++++++++++++++++++++++
modules_s/blst/doc/functions.xml | 80 ++++++++++++++++++++++++++++++++++++++
2 files changed, 127 insertions(+), 0 deletions(-)